Class: WeatherApiTask::Coord
- Defined in:
- lib/weather_api_task/models/coord.rb
Overview
Coord Model.
Instance Attribute Summary collapse
-
#lat ⇒ Float
TODO: Write general description for this method.
-
#lon ⇒ Float
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
Instance Method Summary collapse
-
#initialize(lat = nil, lon = nil) ⇒ Coord
constructor
A new instance of Coord.
Methods inherited from BaseModel
Constructor Details
#initialize(lat = nil, lon = nil) ⇒ Coord
25 26 27 28 29 |
# File 'lib/weather_api_task/models/coord.rb', line 25 def initialize(lat = nil, lon = nil) @lat = lat @lon = lon end |
Instance Attribute Details
#lat ⇒ Float
TODO: Write general description for this method
11 12 13 |
# File 'lib/weather_api_task/models/coord.rb', line 11 def lat @lat end |
#lon ⇒ Float
TODO: Write general description for this method
15 16 17 |
# File 'lib/weather_api_task/models/coord.rb', line 15 def lon @lon end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
32 33 34 35 36 37 38 39 40 41 42 |
# File 'lib/weather_api_task/models/coord.rb', line 32 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. lat = hash['lat'] lon = hash['lon'] # Create object from extracted values. Coord.new(lat, lon) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 23 |
# File 'lib/weather_api_task/models/coord.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['lat'] = 'lat' @_hash['lon'] = 'lon' @_hash end |