Class: WeatherApiTask::Sys
- Defined in:
- lib/weather_api_task/models/sys.rb
Overview
Sys Model.
Instance Attribute Summary collapse
-
#country ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
Instance Method Summary collapse
-
#initialize(country = nil) ⇒ Sys
constructor
A new instance of Sys.
Methods inherited from BaseModel
Constructor Details
#initialize(country = nil) ⇒ Sys
Returns a new instance of Sys.
20 21 22 |
# File 'lib/weather_api_task/models/sys.rb', line 20 def initialize(country = nil) @country = country end |
Instance Attribute Details
#country ⇒ String
TODO: Write general description for this method
11 12 13 |
# File 'lib/weather_api_task/models/sys.rb', line 11 def country @country end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
25 26 27 28 29 30 31 32 33 |
# File 'lib/weather_api_task/models/sys.rb', line 25 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. country = hash['country'] # Create object from extracted values. Sys.new(country) end |
.names ⇒ Object
A mapping from model property names to API property names.
14 15 16 17 18 |
# File 'lib/weather_api_task/models/sys.rb', line 14 def self.names @_hash = {} if @_hash.nil? @_hash['country'] = 'country' @_hash end |